# Tweetcal: Convert a tweet stream to ics calendar
# Copyright (c) 2014 Neil Freeman
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
from . import tweetcal, read_archive

__author__ = 'Neil Freeman'
__license__ = 'GPL-3.0'
__all__ = ['tweetcal']
__version__ = '0.4.5.post1'
